Documentation
==============

Welcome to **NeuroKit**'s documentation. Here you can find information and learn about Python, NeuroKit, Physiological Signals and more.

You can navigate to the different sections using the left panel. We would recommend checking out the **guides** and **examples**, where you can find tutorials and hands-on walkthroughs.

.. toctree::
   :maxdepth: 2

   introduction
   authors
   installation
   start/index
   examples/index
   resources/index
   functions
   studies/index
   datasets
   contributing/index
   

	

.. only:: comment
    Indices and tables
    ==================
    * :ref:`genindex`
    * :ref:`modindex`
    * :ref:`search`
